<div id="top"></div>

<br />
<div align="center">

  <h3 align="center">almirah</h3>

  <p align="center">
	a wardrobe for datasets
	<br />
	<a href="https://girishmm.github.io/almirah"><strong>Explore the docs »</strong></a>
	<br />
	<br />
	<a href="https://github.com/girishmm/almirah/issues">Report Bug</a>
	·
	<a href="https://github.com/girishmm/almirah/issues">Request Feature</a>
  </p>
</div>

## About The Project

Clothes can be organized, maintained, and easily accessed from a
wardrobe. [almirah](https://github.com/girishmm/almirah) serves the
same purpose for datasets.

You can define the method to follow to stack your contents on the
almirah, and even tag. [almirah](https://github.com/girishmm/almirah)
hopes to make working with datasets easier.

<p align="right">(<a href="#top">back to top</a>)</p>

## Acknowledgments

Thanks to Upi and Bhalla lab members for their inputs and help.

<p align="right">(<a href="#top">back to top</a>)</p>
